93355a504a563b0e365231e32a3f71174e2b3884
galt
  Wed Jun 12 01:48:55 2019 -0700
Increase background timeout wait. Genome-euro machine is not as fast. refs #23628.

diff --git src/hg/hgSession/backup.c src/hg/hgSession/backup.c
index cb79263..76a80b8 100644
--- src/hg/hgSession/backup.c
+++ src/hg/hgSession/backup.c
@@ -74,32 +74,32 @@
 {
 popWarnHandler();
 cartWebEnd();
 }
 
 // ------------------------------------------
 
 
 void getBackgroundStatus(char *url)
 /* fetch status as the latest complete html block available.
  * fetch progress info instead if background proc still running. */
 {
 char *html = NULL;
 int waited = 0;
 // sometimes the background process is a little slow,
-// we can wait up to 30 seconds for it.
-while ((fileSize(url)==0) && (waited < 30))
+// we can wait up to 60 seconds for it.
+while ((fileSize(url)==0) && (waited < 60))
     {
     sleep(1);
     ++waited;
     }
 if (fileSize(url)==0)
     {
     htmlOpen("Background Status");
     errAbort("No output found. Expecting output in [%s].", url);
     htmlClose();
     return;
     }
 
 // get the pid and see if it is still running
 char pidName[1024];
 safef(pidName, sizeof pidName, "%s.pid", url);